@@ -58,15 +58,21 @@
           (nreverse candidates)
         (user-error "No outline")))))
 
-(defun denote-org-extras--outline-prompt (&optional file)
+(define-obsolete-function-alias
+  'denote-org-extras--outline-prompt
+  'denote-org-extras-outline-prompt
+  "3.1.0")
+
+(defun denote-org-extras-outline-prompt (&optional file)
   "Prompt for outline among headings retrieved by `denote-org-extras--get-outline'.
 With optional FILE use the outline of it, otherwise use that of
 the current file."
-  (completing-read
-   (format "Select heading inside `%s': "
-           (propertize (file-name-nondirectory file) 'face 'denote-faces-prompt-current-name))
-   (denote--completion-table-no-sort 'imenu (denote-org-extras--get-outline (or file buffer-file-name)))
-   nil :require-match))
+  (let ((current-file (or file buffer-file-name)))
+    (completing-read
+     (format "Select heading inside `%s': "
+             (propertize (file-name-nondirectory current-file) 'face 'denote-faces-prompt-current-name))
+     (denote--completion-table-no-sort 'imenu (denote-org-extras--get-outline current-file))
+     nil :require-match)))
 
 (defun denote-org-extras--get-heading-and-id-from-line (line file)
   "Return heading text and CUSTOM_ID from the given LINE in FILE."
@@ -114,7 +120,7 @@ Also see `denote-org-extras-backlinks-for-heading'."
     (user-error "Links to headings only work between Org files"))
   (when-let ((file (denote-file-prompt ".*\\.org"))
              (file-text (denote--link-get-description file))
-             (heading (denote-org-extras--outline-prompt file))
+             (heading (denote-org-extras-outline-prompt file))
              (line (string-to-number (car (split-string heading "\t"))))
              (heading-data (denote-org-extras--get-heading-and-id-from-line line file))
              (heading-text (car heading-data))
